aboutsummaryrefslogtreecommitdiff
path: root/libjava/gnu
diff options
context:
space:
mode:
authorTom Tromey <tromey@redhat.com>2001-09-05 00:00:55 +0000
committerTom Tromey <tromey@gcc.gnu.org>2001-09-05 00:00:55 +0000
commita1f4e5ed0ad7c060fc1b90c3b363877cb8cca198 (patch)
treee84d2d5f42b8908733b2858f19c7f95e32335a86 /libjava/gnu
parent45932d27fb140524de00d4a08efea4cf75dd7ca0 (diff)
downloadgcc-a1f4e5ed0ad7c060fc1b90c3b363877cb8cca198.zip
gcc-a1f4e5ed0ad7c060fc1b90c3b363877cb8cca198.tar.gz
gcc-a1f4e5ed0ad7c060fc1b90c3b363877cb8cca198.tar.bz2
SimpleDateFormat.java: Re-merged with Classpath.
* java/text/SimpleDateFormat.java: Re-merged with Classpath. * gnu/gcj/text/LocaleData.java, gnu/gcj/text/LocaleData_en.java, gnu/gcj/text/LocaleData_en_US.java: Removed. * java/text/DateFormatSymbols.java (clone): Use Classpath implementation. (equals): Simplified. (DateFormatSymbols): Look in gnu.java.locale for information. (DateFormatSymbols(DateFormatSymbols)): Removed. (safeGetResource): Removed. (DateFormatSymbols): Throws MissingResourceException. (ampmsDefault, erasDefault, localPatternCharsDefault, monthsDefault, shortMonthsDefault, shortWeekdaysDefault, weekdaysDefault, zoneStringsDefault): Removed. * java/text/Collator.java (getAvailableLocales): Use modified Classpath implementation. (getInstance): Look in gnu.java.locale for information. (clone): Rewrote. * java/text/MessageFormat.java: Reindented. (clone): Rewrote. * java/text/FieldPosition.java: Merged with Classpath. * java/text/ParsePosition.java: Merged with Classpath. * java/text/Format.java: Merged with Classpath. * java/text/StringCharacterIterator.java (StringCharacterIterator(StringCharacterIterator,int,int)): New constructor from Classpath. * java/text/Annotation.java, java/text/AttributedCharacterIterator.java, java/text/AttributedString.java, java/text/AttributedStringIterator.java: New from Classpath. * java/text/CharacterIterator.java: Copied from Classpath. * java/text/ChoiceFormat.java: Reindented. (clone): Removed. * gnu/java/text/BaseBreakIterator.java, gnu/java/text/CharacterBreakIterator.java, gnu/java/text/LineBreakIterator.java, gnu/java/text/LocaleData_en.java, gnu/java/text/LocaleData_en_US.java, gnu/java/text/SentenceBreakIterator.java, gnu/java/text/WordBreakIterator.java: Renamed from gnu/gcj/text/*. * gnu/gcj/text/BaseBreakIterator.java (last): Advance past final character. * java/text/BreakIterator.java (getAvailableLocales): Use Classpath implementation. (getInstance): Look in gnu.java.locale for information. (getCharacterInstance, getLineInstance, getSentenceInstance, getWordInstance): Look in gnu.java.text for implementations. * java/text/DecimalFormatSymbols.java: Reindented (clone): Use Classpath implementation. (DecimalFormatSymbols(DecimalFormatSymbols)): Removed. (DecimalFormatSymbols(Locale)): Look in gnu.java.locale for information. * java/text/DateFormat.java: Merged with Classpath. (getAvailableLocales): Use Classpath implementation. (format(Object,StringBuffer,FieldPosition)): Minor cleanup. (computeInstance): Look in gnu.java.locale for information. * java/text/NumberFormat.java: Reindented. (computeInstance): Look in gnu.java.locale for information. (getAvailableLocales): Use implementation from Classpath. (setMaximumIntegerDigits): Likewise. (setMinimumIntegerDigits): Likewise. (setMaximumFractionDigits): Likewise. (clone): Removed. * java/text/DecimalFormat.java: Reindented. * gnu/java/locale/LocaleInformation_en.java: Copied from Classpath. * gnu/java/locale/LocaleInformation_en_US.java: Copied from Classpath. * Makefile.in: Rebuilt. * Makefile.am (ordinary_java_source_files): Added all new files. (ordinary_java_source_files): Renamed or removed gnu/gcj/text/*. * java/security/spec/AlgorithmParameterSpec.java, java/security/spec/KeySpec.java: Re-merged with Classpath. From-SVN: r45390
Diffstat (limited to 'libjava/gnu')
-rw-r--r--libjava/gnu/gcj/text/BaseBreakIterator.java82
-rw-r--r--libjava/gnu/gcj/text/LocaleData.java25
-rw-r--r--libjava/gnu/gcj/text/LocaleData_en.java92
-rw-r--r--libjava/gnu/gcj/text/LocaleData_en_US.java81
-rw-r--r--libjava/gnu/java/locale/LocaleInformation_de.java4
-rw-r--r--libjava/gnu/java/locale/LocaleInformation_en.java408
-rw-r--r--libjava/gnu/java/locale/LocaleInformation_en_US.java112
-rw-r--r--libjava/gnu/java/locale/LocaleInformation_nl.java38
-rw-r--r--libjava/gnu/java/text/BaseBreakIterator.java101
-rw-r--r--libjava/gnu/java/text/CharacterBreakIterator.java (renamed from libjava/gnu/gcj/text/CharacterBreakIterator.java)39
-rw-r--r--libjava/gnu/java/text/LineBreakIterator.java (renamed from libjava/gnu/gcj/text/LineBreakIterator.java)39
-rw-r--r--libjava/gnu/java/text/SentenceBreakIterator.java (renamed from libjava/gnu/gcj/text/SentenceBreakIterator.java)39
-rw-r--r--libjava/gnu/java/text/WordBreakIterator.java (renamed from libjava/gnu/gcj/text/WordBreakIterator.java)39
13 files changed, 444 insertions, 655 deletions
diff --git a/libjava/gnu/gcj/text/BaseBreakIterator.java b/libjava/gnu/gcj/text/BaseBreakIterator.java
deleted file mode 100644
index 8c20d46..0000000
--- a/libjava/gnu/gcj/text/BaseBreakIterator.java
+++ /dev/null
@@ -1,82 +0,0 @@
-// Base class for default BreakIterators.
-
-/* Copyright (C) 1999 Free Software Foundation
-
- This file is part of libgcj.
-
-This software is copyrighted work licensed under the terms of the
-Libgcj License. Please consult the file "LIBGCJ_LICENSE" for
-details. */
-
-package gnu.gcj.text;
-
-import java.text.BreakIterator;
-import java.text.CharacterIterator;
-
-/**
- * @author Tom Tromey <tromey@cygnus.com>
- * @date March 22, 1999
- */
-
-public abstract class BaseBreakIterator extends BreakIterator
-{
- public int current ()
- {
- return iter.getIndex();
- }
-
- public int first ()
- {
- iter.first();
- return iter.getBeginIndex();
- }
-
- public int following (int pos)
- {
- int save = iter.getIndex();
- iter.setIndex(pos);
- int r = next ();
- iter.setIndex(save);
- return r;
- }
-
- public CharacterIterator getText ()
- {
- return iter;
- }
-
- public int last ()
- {
- iter.last();
- return iter.getEndIndex();
- }
-
- public int next (int n)
- {
- int r = iter.getIndex ();
- if (n > 0)
- {
- while (n > 0 && r != DONE)
- {
- r = next ();
- --n;
- }
- }
- else if (n < 0)
- {
- while (n < 0 && r != DONE)
- {
- r = previous ();
- ++n;
- }
- }
- return r;
- }
-
- public void setText (CharacterIterator newText)
- {
- iter = newText;
- }
-
- protected CharacterIterator iter;
-}
diff --git a/libjava/gnu/gcj/text/LocaleData.java b/libjava/gnu/gcj/text/LocaleData.java
deleted file mode 100644
index fc273b9..0000000
--- a/libjava/gnu/gcj/text/LocaleData.java
+++ /dev/null
@@ -1,25 +0,0 @@
-// Generic locale data for java.text.
-
-/* Copyright (C) 2001 Free Software Foundation
-
- This file is part of libgcj.
-
-This software is copyrighted work licensed under the terms of the
-Libgcj License. Please consult the file "LIBGCJ_LICENSE" for
-details. */
-
-package gnu.gcj.text;
-
-import java.util.ListResourceBundle;
-
-public class LocaleData extends ListResourceBundle
-{
- private static final Object[][] contents =
- {
- };
-
- protected Object[][] getContents ()
- {
- return contents;
- }
-}
diff --git a/libjava/gnu/gcj/text/LocaleData_en.java b/libjava/gnu/gcj/text/LocaleData_en.java
deleted file mode 100644
index c24c1121..0000000
--- a/libjava/gnu/gcj/text/LocaleData_en.java
+++ /dev/null
@@ -1,92 +0,0 @@
-// Generic English locale data for java.text.
-
-/* Copyright (C) 1999, 2000 Free Software Foundation
-
- This file is part of libgcj.
-
-This software is copyrighted work licensed under the terms of the
-Libgcj License. Please consult the file "LIBGCJ_LICENSE" for
-details. */
-
-package gnu.gcj.text;
-
-import java.util.ListResourceBundle;
-
-/**
- * @author Tom Tromey <tromey@cygnus.com>
- * @date March 4, 1999
- */
-
-public final class LocaleData_en extends ListResourceBundle
-{
- // These are for DateFormatSymbols.
- static final String[] ampmsDefault = {"AM", "PM" };
- static final String[] erasDefault = {"BC", "AD" };
- static final String localPatternCharsDefault = "GyMdkHmsSEDFwWahKz";
- static final String[] monthsDefault = {
- "January", "February", "March", "April", "May", "June",
- "July", "August", "September", "October", "November", "December", ""
- };
- static final String[] shortMonthsDefault = {
- "Jan", "Feb", "Mar", "Apr", "May", "Jun",
- "Jul", "Aug", "Sep", "Oct", "Nov", "Dec", ""
- };
- static final String[] shortWeekdaysDefault = {
- "", "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"
- };
- static final String[] weekdaysDefault = {
- "", "Sunday", "Monday", "Tuesday",
- "Wednesday", "Thursday", "Friday", "Saturday"
- };
-
- private static final Object[][] contents =
- {
- // These are for DecimalFormatSymbols.
- { "decimalSeparator", "." },
- { "digit", "#" },
- { "exponential", "E" },
- { "groupingSeparator", "," },
- { "infinity", "\u221e" },
- { "minusSign", "-" },
- { "monetarySeparator", "." },
- { "NaN", "\ufffd" },
- { "patternSeparator", ";" },
- { "percent", "%" },
- { "perMill", "\u2030" },
- { "zeroDigit", "0" },
-
- // These are for NumberFormat.
- { "numberFormat", "#,##0.###" },
- { "percentFormat", "#,##0%" },
-
- // These are for DateFormatSymbols.
- { "ampm", ampmsDefault },
- { "eras", erasDefault },
- { "datePatternChars", localPatternCharsDefault },
- { "months", monthsDefault },
- { "shortMonths", shortMonthsDefault },
- { "shortWeekdays", shortWeekdaysDefault },
- { "weekdays", weekdaysDefault },
-
- // These are for DateFormat.
- { "shortDateFormat", "M/d/yy" }, // Java's Y2K bug.
- { "mediumDateFormat", "d-MMM-yy" },
- { "longDateFormat", "MMMM d, yyyy" },
- { "fullDateFormat", "EEEE MMMM d, yyyy G" },
- { "shortTimeFormat", "h:mm a" },
- { "mediumTimeFormat", "h:mm:ss a" },
- { "longTimeFormat", "h:mm:ss a z" },
- { "fullTimeFormat", "h:mm:ss;S 'o''clock' a z" },
-
- // For RuleBasedCollator.
- // FIXME: this is nowhere near complete.
- // In particular we must mark accents as ignorable,
- // and probably other things as well.
- { "collatorRule", "< 0 < 1 < 2 < 3 < 4 < 5 < 6 < 7 < 8 < 9 < a,A < b,B < c,C < d,D < e,E < f,F < g,G < h,H < i,I < j,J < k,K < l,L < m,M < n,N < o,O < p,P < q,Q < r,R < s,S < t,T < u,U < v,V < w,W < x,X < y,Y < z,Z" }
- };
-
- protected Object[][] getContents ()
- {
- return contents;
- }
-}
diff --git a/libjava/gnu/gcj/text/LocaleData_en_US.java b/libjava/gnu/gcj/text/LocaleData_en_US.java
deleted file mode 100644
index eb5d4f1..0000000
--- a/libjava/gnu/gcj/text/LocaleData_en_US.java
+++ /dev/null
@@ -1,81 +0,0 @@
-// US English locale data for java.text.
-
-/* Copyright (C) 1999 Free Software Foundation
-
- This file is part of libgcj.
-
-This software is copyrighted work licensed under the terms of the
-Libgcj License. Please consult the file "LIBGCJ_LICENSE" for
-details. */
-
-package gnu.gcj.text;
-
-import java.util.ListResourceBundle;
-
-/**
- * @author Tom Tromey <tromey@cygnus.com>
- * @date March 4, 1999
- */
-
-public final class LocaleData_en_US extends ListResourceBundle
-{
- // These are for DateFormatSymbols.
- static String[][] zoneStringsDefault = {
- { "GMT", "Greenwich Mean Time", "GMT",
- /**/ "Greenwich Mean Time", "GMT", "GMT" },
- { "PST", "Pacific Standard Time", "PST",
- /**/ "Pacific Daylight Time", "PDT", "San Francisco" },
- { "MST", "Mountain Standard Time", "MST",
- /**/ "Mountain Daylight Time", "MDT", "Denver" },
- { "PNT", "Mountain Standard Time", "MST",
- /**/ "Mountain Standard Time", "MST", "Phoenix" },
- { "CST", "Central Standard Time", "CST",
- /**/ "Central Daylight Time", "CDT", "Chicago" },
- { "EST", "Eastern Standard Time", "EST",
- /**/ "Eastern Daylight Time", "EDT", "Boston" },
- { "IET", "Eastern Standard Time", "EST",
- /**/ "Eastern Standard Time", "EST", "Indianapolis" },
- { "PRT", "Atlantic Standard Time", "AST",
- /**/ "Atlantic Daylight Time", "ADT", "Halifax" },
- { "CNT", "Newfoundland Standard Time", "NST",
- /**/ "Newfoundland Daylight Time", "NDT", "St. Johns" },
- { "ECT", "Central European Standard Time", "CET",
- /**/ "Central European Daylight Time", "CEST", "Paris" },
- { "CTT", "China Standard Time", "CST",
- /**/ "China Standard Time", "CST", "Shanghai" },
- { "JST", "Japan Standard Time", "JST",
- /**/ "Japan Standard Time", "JST", "Tokyo" },
- { "HST", "Hawaii Standard Time", "HST",
- /**/ "Hawaii Standard Time", "HST", "Honolulu" },
- { "AST", "Alaska Standard Time", "AKST",
- /**/ "Alaska Daylight Time", "AKDT", "Anchorage" }
- };
-
- private static final Object[][] contents =
- {
- // These are for DecimalFormatSymbols.
- { "currency", "$" },
- { "intlCurrencySymbol", "$" }, // FIXME?
-
- // These are for NumberFormat.
- { "currencyFormat", "$#,##0.00;($#,##0.00)" },
-
- // These are for DateFormatSymbols.
- { "zoneStrings", zoneStringsDefault },
-
- // These are for DateFormat.
- { "shortDateFormat", "M/d/yy" }, // Java's Y2K bug.
- { "mediumDateFormat", "d-MMM-yy" },
- { "longDateFormat", "MMMM d, yyyy" },
- { "fullDateFormat", "EEEE MMMM d, yyyy G" },
- { "shortTimeFormat", "h:mm a" },
- { "mediumTimeFormat", "h:mm:ss a" },
- { "longTimeFormat", "h:mm:ss a z" },
- { "fullTimeFormat", "h:mm:ss;S 'o''clock' a z" }
- };
-
- protected Object[][] getContents ()
- {
- return contents;
- }
-}
diff --git a/libjava/gnu/java/locale/LocaleInformation_de.java b/libjava/gnu/java/locale/LocaleInformation_de.java
index 5eea905..208f2c5 100644
--- a/libjava/gnu/java/locale/LocaleInformation_de.java
+++ b/libjava/gnu/java/locale/LocaleInformation_de.java
@@ -1,5 +1,5 @@
/* LocaleInformation_de.java -- German locale data
- Copyright (C) 1999 Free Software Foundation, Inc.
+ Copyright (C) 1999, 2001 Free Software Foundation, Inc.
This file is part of GNU Classpath.
@@ -47,7 +47,7 @@ public class LocaleInformation_de extends ListResourceBundle
* proper format.
*/
private static final String collation_rules =
- "-<0,1<2<3<4<5<6<7<8<9<A,a<b,B<c,C<d,D<e,E<f,F<g,G<h,H<i,I<j,J<j,K" +
+ "<0<1<2<3<4<5<6<7<8<9<A,a<b,B<c,C<d,D<e,E<f,F<g,G<h,H<i,I<j,J<k,K" +
"<l,L<m,M<n,N<o,O<p,P<q,Q<r,R<s,S<t,T<u,U<v,V<w,W<x,X<y,Y,z<Z" +
"&ae,\u00e4&Ae,\u00c4&oe,\u00f6&Oe,\u00d6&ue,\u00fc&Ue,\u00dc&ss,\u00df";
diff --git a/libjava/gnu/java/locale/LocaleInformation_en.java b/libjava/gnu/java/locale/LocaleInformation_en.java
index 22e7371..61e351d 100644
--- a/libjava/gnu/java/locale/LocaleInformation_en.java
+++ b/libjava/gnu/java/locale/LocaleInformation_en.java
@@ -1,5 +1,5 @@
/* LocaleInformation_en.java -- US English locale data
- Copyright (C) 1998, 1999 Free Software Foundation, Inc.
+ Copyright (C) 1998, 1999, 2001 Free Software Foundation, Inc.
This file is part of GNU Classpath.
@@ -32,301 +32,123 @@ import java.util.Calendar;
import java.util.Date;
/**
- * This class contains locale data for the US English locale
- */
-
+ * This class contains locale data for English.
+ */
public class LocaleInformation_en extends ListResourceBundle
{
-/*
- * This area is used for defining object values
- */
-
-/**
- * This is the set of collation rules used by java.text.RuleBasedCollator
- * to sort strings properly. See the documentation of that class for the
- * proper format.
- */
-private static final String collation_rules =
- "-<0,1<2<3<4<5<6<7<8<9A,a<b,B<c,C<d,D<e,E<f,F<g,G<h,H<i,I<j,J<j,K" +
+ /*
+ * This area is used for defining object values
+ */
+
+ /**
+ * This is the set of collation rules used by java.text.RuleBasedCollator
+ * to sort strings properly. See the documentation of that class for the
+ * proper format.
+ */
+ // FIXME: this is nowhere near complete.
+ // In particular we must mark accents as ignorable,
+ // and probably other things as well.
+ private static final String collation_rules =
+ "<0<1<2<3<4<5<6<7<8<9<A,a<b,B<c,C<d,D<e,E<f,F<g,G<h,H<i,I<j,J<k,K" +
"<l,L<m,M<n,N<o,O<p,P<q,Q<r,R<s,S<t,T<u,U<v,V<w,W<x,X<y,Y,z<Z";
-/*
- * For the followings lists, strings that are subsets of other break strigns
- * must be listed first. For example, if "\r" and "\r\n" are sequences,
- * the "\r" must be first or it will never be used.
- */
-
-/**
- * This is the list of word separator characters used by
- * java.text.BreakIterator
- */
-private static final String[] word_breaks = { " ", "\t", "\r\n", "\n" };
-
-/**
- * This is the list of sentence break sequences used by
- * java.text.BreakIterator
- */
-private static final String[] sentence_breaks = { ". " };
-
-/**
- * This is the list of potential line break locations.
- */
-private static final String[] line_breaks = { "\t", "-", "\r\n",
- "\n", ". ", ". ", ".", "? ", "? ", "?", "! ", "! ", "!", ", ", " " };
-
-/**
- * This is the list of months, fully spelled out
- */
-private static final String[] months = { "January", "February", "March",
- "April", "May", "June", "July", "August", "September", "October",
- "November", "December", null };
-
-/**
- * This is the list of abbreviated month names
- */
-private static final String[] shortMonths = { "Jan", "Feb", "Mar", "Apr", "May",
- "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec", null };
-
-/**
- * This is the list of weekdays, fully spelled out
- */
-private static final String[] weekdays = { null, "Sunday", "Monday", "Tuesday",
- "Wednesday", "Thursday", "Friday", "Saturday" };
-
-/**
- * This is the list of abbreviated weekdays
- */
-private static final String[] shortWeekdays = { null, "Sun", "Mon", "Tue", "Wed",
- "Thu", "Fri", "Sat" };
-
-/**
- * This is the list of AM/PM strings
- */
-private static final String[] ampms = { "AM", "PM" };
-
-/**
- * This is the list of era identifiers
- */
-private static final String[] eras = { "BC", "AD" };
-
-/**
- * This is the list of timezone strings. The JDK appears to include a
- * city name as the sixth element.
- */
-private static final String[][] zoneStrings =
-{
- { "EST6EDT", "Eastern Standard Time", "EST", "Eastern Daylight Time", "EDT",
- "New York" },
- { "EST6", "Eastern Standard Time", "EST", "Eastern Standard Time", "EST",
- "Indianapolis" },
- { "CST6CDT", "Central Standard Time", "CST", "Central Daylight Time", "CDT",
- "Chicago" },
- { "MST6MDT", "Mountain Standard Time", "MST", "Mountain Daylight Time",
- "MDT", "Denver" },
- { "MST6", "Mountain Standard Time", "MST", "Mountain Standard Time", "MST",
- "Phoenix" },
- { "PST6PDT", "Pacific Standard Time", "PDT", "Pacific Daylight Time", "PDT",
- "San Francisco" },
- { "AST6ADT", "Alaska Standard Time", "AST", "Alaska Daylight Time", "ADT",
- "Anchorage" },
- { "HST6HDT", "Hawaii Standard Time", "HST", "Hawaii Daylight Time", "HDT",
- "Honolulu" },
- // European time zones. The city names are a little bit random.
- { "WET", "Western European Time", "WET", "Western European Savings Time", "WEST", "London" },
- { "CET", "Central European Time", "CET", "Central European Savings Time", "CEST", "Berlin" },
- { "EET", "Eastern European Time", "EET", "Eastern European Savings Time", "EEST", "Istanbul" },
-};
-
-/**
- * This is the list of pattern characters for formatting dates
- */
-private static final String localPatternChars = "GyMdkHmsSEDFwWahKz"; // Not a mistake!
-
-/**
- * This is the DateFormat.SHORT date format
- */
-private static final String shortDateFormat = "M/d/yy";
-
-/**
- * This is the DateFormat.MEDIUM format
- */
-private static final String mediumDateFormat = "dd-MMM-yy";
-
-/**
- * This is the DateFormat.LONG format
- */
-private static final String longDateFormat = "MMMM d, yyyy";
-
-/**
- * This is the DateFormat.FULL format
- */
-private static final String fullDateFormat = "EEEE, MMMM d, yyyy";
-
-/**
- * This is the DateFormat.DEFAULT format
- */
-private static final String defaultDateFormat = "dd-MMM-yy";
-
-/**
- * This is the DateFormat.SHORT format
- */
-private static final String shortTimeFormat = "h:mm a";
-
-/**
- * This is the DateFormat.MEDIUM format
- */
-private static final String mediumTimeFormat = "h:mm:ss a";
-
-/**
- * This is the DateFormat.LONG format
- */
-private static final String longTimeFormat = "h:mm:ss a z";
-
-/**
- * This is the DateFormat.FULL format
- */
-private static final String fullTimeFormat = "h:mm:ss 'o''clock' a z";
-
-/**
- * This is the DateFormat.DEFAULT format
- */
-private static final String defaultTimeFormat = "h:mm:ss a";
-
-/**
- * This is the currency symbol
- */
-private static final String currencySymbol = "$";
-
-/**
- * This is the international currency symbol.
- */
-private static final String intlCurrencySymbol = "US$";
-
-/**
- * This is the decimal point.
- */
-private static final String decimalSeparator = ".";
-
-/**
- * This is the exponential symbol
- */
-private static final String exponential = "E";
-
-/**
- * This is the char used for digits in format strings
- */
-private static final String digit = "#";
-
-/**
- * This is the grouping separator symbols
- */
-private static final String groupingSeparator = ",";
-
-/**
- * This is the symbols for infinity
- */
-private static final String infinity = "\u221e";
-
-/**
- * This is the symbol for the not a number value
- */
-private static final String NaN = "\ufffd";
-
-/**
- * This is the minus sign symbol.
- */
-private static final String minusSign = "-";
-
-/**
- * This is the decimal separator in monetary values.
- */
-private static final String monetarySeparator = ".";
-
-/**
- * This is the separator between positive and negative subpatterns.
- */
-private static final String patternSeparator = ";";
-
-/**
- * This is the percent sign
- */
-private static final String percent = "%";
-
-/**
- * This is the per mille sign
- */
-private static final String perMill = "\u2030";
-
-/**
- * This is the character for zero.
- */
-private static final String zeroDigit = "0";
-
-/*************************************************************************/
-
-/**
- * This is the object array used to hold the keys and values
- * for this bundle
- */
-
-private static final Object[][] contents =
-{
- // For RuleBasedCollator
- { "collation_rules", collation_rules },
- // For BreakIterator
- { "word_breaks", word_breaks },
- { "sentence_breaks", sentence_breaks },
- { "line_breaks", line_breaks },
- // For SimpleDateFormat/DateFormatSymbols
- { "months", months },
- { "shortMonths", shortMonths },
- { "weekdays", weekdays },
- { "shortWeekdays", shortWeekdays },
- { "ampms", ampms },
- { "eras", eras },
- { "zoneStrings", zoneStrings },
- { "localPatternChars", localPatternChars },
- { "shortDateFormat", shortDateFormat },
- { "mediumDateFormat", mediumDateFormat },
- { "longDateFormat", longDateFormat },
- { "fullDateFormat", fullDateFormat },
- { "defaultDateFormat", defaultDateFormat },
- { "shortTimeFormat", shortTimeFormat },
- { "mediumTimeFormat", mediumTimeFormat },
- { "longTimeFormat", longTimeFormat },
- { "fullTimeFormat", fullTimeFormat },
- { "defaultTimeFormat", defaultTimeFormat },
- // For DecimalFormat/DecimalFormatSymbols
- { "currencySymbol", currencySymbol },
- { "intlCurrencySymbol", intlCurrencySymbol },
- { "decimalSeparator", decimalSeparator },
- { "digit", digit },
- { "exponential", exponential },
- { "groupingSeparator", groupingSeparator },
- { "infinity", infinity },
- { "NaN", NaN },
- { "minusSign", minusSign },
- { "monetarySeparator", monetarySeparator },
- { "patternSeparator", patternSeparator },
- { "percent", percent },
- { "perMill", perMill },
- { "zeroDigit", zeroDigit },
-};
-
-/*************************************************************************/
-
-/**
- * This method returns the object array of key, value pairs containing
- * the data for this bundle.
- *
- * @return The key, value information.
- */
-public Object[][]
-getContents()
-{
- return(contents);
+ /**
+ * This is the list of months, fully spelled out
+ */
+ private static final String[] months =
+ {
+ "January", "February", "March", "April", "May", "June",
+ "July", "August", "September", "October", "November", "December", null
+ };
+
+ /**
+ * This is the list of abbreviated month names
+ */
+ private static final String[] shortMonths =
+ {
+ "Jan", "Feb", "Mar", "Apr", "May", "Jun",
+ "Jul", "Aug", "Sep", "Oct", "Nov", "Dec", null
+ };
+
+ /**
+ * This is the list of weekdays, fully spelled out
+ */
+ private static final String[] weekdays =
+ {
+ null, "Sunday", "Monday", "Tuesday", "Wednesday",
+ "Thursday", "Friday", "Saturday"
+ };
+
+ /**
+ * This is the list of abbreviated weekdays
+ */
+ private static final String[] shortWeekdays =
+ {
+ null, "Sun", "Mon", "Tue", "Wed",
+ "Thu", "Fri", "Sat"
+ };
+
+ /**
+ * This is the list of AM/PM strings
+ */
+ private static final String[] ampms = { "AM", "PM" };
+
+ /**
+ * This is the list of era identifiers
+ */
+ private static final String[] eras = { "BC", "AD" };
+
+ /*************************************************************************/
+
+ /**
+ * This is the object array used to hold the keys and values
+ * for this bundle
+ */
+
+ private static final Object[][] contents =
+ {
+ // For RuleBasedCollator
+ { "collation_rules", collation_rules },
+
+ // For SimpleDateFormat/DateFormatSymbols
+ { "months", months },
+ { "shortMonths", shortMonths },
+ { "weekdays", weekdays },
+ { "shortWeekdays", shortWeekdays },
+ { "ampms", ampms },
+ { "eras", eras },
+ { "localPatternChars", "GyMdkHmsSEDFwWahKz" },
+
+ // For DecimalFormat/DecimalFormatSymbols
+ { "decimalSeparator", "." },
+ { "digit", "#" },
+ { "exponential", "E" },
+ { "groupingSeparator", "," },
+ { "infinity", "\u221e" },
+ { "NaN", "\ufffd" },
+ { "minusSign", "-" },
+ { "monetarySeparator", "." },
+ { "patternSeparator", ";" },
+ { "percent", "%" },
+ { "perMill", "\u2030" },
+ { "zeroDigit", "0" },
+
+ // For NumberFormat.
+ { "numberFormat", "#,##0.###" },
+ { "percentFormat", "#,##0%" },
+ };
+
+ /*************************************************************************/
+
+ /**
+ * This method returns the object array of key, value pairs containing
+ * the data for this bundle.
+ *
+ * @return The key, value information.
+ */
+ public Object[][] getContents ()
+ {
+ return contents;
+ }
}
-
-} // class LocaleInformation_en
-
diff --git a/libjava/gnu/java/locale/LocaleInformation_en_US.java b/libjava/gnu/java/locale/LocaleInformation_en_US.java
new file mode 100644
index 0000000..1278ccd
--- /dev/null
+++ b/libjava/gnu/java/locale/LocaleInformation_en_US.java
@@ -0,0 +1,112 @@
+/* LocaleInformation_en.java -- US English locale data
+ Copyright (C) 1998, 1999, 2001 Free Software Foundation, Inc.
+
+This file is part of GNU Classpath.
+
+GNU Classpath is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+GNU Classpath is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with GNU Classpath; see the file COPYING. If not, write to the
+Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+02111-1307 USA.
+
+As a special exception, if you link this library with other files to
+produce an executable, this library does not by itself cause the
+resulting executable to be covered by the GNU General Public License.
+This exception does not however invalidate any other reasons why the
+executable file might be covered by the GNU General Public License. */
+
+
+package gnu.java.locale;
+
+import java.util.ListResourceBundle;
+import java.util.Calendar;
+import java.util.Date;
+
+/**
+ * This class contains locale data for English in the US.
+ */
+public class LocaleInformation_en_US extends ListResourceBundle
+{
+ // These are for DateFormatSymbols.
+ private static final String[][] zoneStrings =
+ {
+ { "GMT", "Greenwich Mean Time", "GMT",
+ /**/ "Greenwich Mean Time", "GMT", "GMT" },
+ { "PST", "Pacific Standard Time", "PST",
+ /**/ "Pacific Daylight Time", "PDT", "San Francisco" },
+ { "MST", "Mountain Standard Time", "MST",
+ /**/ "Mountain Daylight Time", "MDT", "Denver" },
+ { "PNT", "Mountain Standard Time", "MST",
+ /**/ "Mountain Standard Time", "MST", "Phoenix" },
+ { "CST", "Central Standard Time", "CST",
+ /**/ "Central Daylight Time", "CDT", "Chicago" },
+ { "EST", "Eastern Standard Time", "EST",
+ /**/ "Eastern Daylight Time", "EDT", "Boston" },
+ { "IET", "Eastern Standard Time", "EST",
+ /**/ "Eastern Standard Time", "EST", "Indianapolis" },
+ { "PRT", "Atlantic Standard Time", "AST",
+ /**/ "Atlantic Daylight Time", "ADT", "Halifax" },
+ { "CNT", "Newfoundland Standard Time", "NST",
+ /**/ "Newfoundland Daylight Time", "NDT", "St. Johns" },
+ { "ECT", "Central European Standard Time", "CET",
+ /**/ "Central European Daylight Time", "CEST", "Paris" },
+ { "CTT", "China Standard Time", "CST",
+ /**/ "China Standard Time", "CST", "Shanghai" },
+ { "JST", "Japan Standard Time", "JST",
+ /**/ "Japan Standard Time", "JST", "Tokyo" },
+ { "HST", "Hawaii Standard Time", "HST",
+ /**/ "Hawaii Standard Time", "HST", "Honolulu" },
+ { "AST", "Alaska Standard Time", "AKST",
+ /**/ "Alaska Daylight Time", "AKDT", "Anchorage" }
+ };
+
+ /**
+ * This is the object array used to hold the keys and values
+ * for this bundle
+ */
+
+ private static final Object[][] contents =
+ {
+ // For SimpleDateFormat/DateFormatSymbols
+ { "zoneStrings", zoneStrings },
+ { "shortDateFormat", "M/d/yy" }, // Java's Y2K bug.
+ { "mediumDateFormat", "d-MMM-yy" },
+ { "longDateFormat", "MMMM d, yyyy" },
+ { "defaultDateFormat", "d-MMMM-yy" },
+ { "fullDateFormat", "EEEE MMMM d, yyyy G" },
+ { "shortTimeFormat", "h:mm a" },
+ { "mediumTimeFormat", "h:mm:ss a" },
+ { "longTimeFormat", "h:mm:ss a z" },
+ { "fullTimeFormat", "h:mm:ss;S 'o''clock' a z" },
+ { "defaultTimeFormat", "h:mm:ss a" },
+
+ // For DecimalFormat/DecimalFormatSymbols
+ { "currencySymbol", "$" },
+ { "intlCurrencySymbol", "US$" },
+
+ // For NumberFormat.
+ { "currencyFormat", "$#,##0.00;($#,##0.00)" }
+ };
+
+ /*************************************************************************/
+
+ /**
+ * This method returns the object array of key, value pairs containing
+ * the data for this bundle.
+ *
+ * @return The key, value information.
+ */
+ public Object[][] getContents ()
+ {
+ return contents;
+ }
+}
diff --git a/libjava/gnu/java/locale/LocaleInformation_nl.java b/libjava/gnu/java/locale/LocaleInformation_nl.java
index 8b74c5b..43cdeb2 100644
--- a/libjava/gnu/java/locale/LocaleInformation_nl.java
+++ b/libjava/gnu/java/locale/LocaleInformation_nl.java
@@ -1,5 +1,5 @@
/* LocaleInformation_nl.java -- Dutch locale data
- Copyright (C) 1999 Free Software Foundation, Inc.
+ Copyright (C) 1999, 2001 Free Software Foundation, Inc.
This file is part of GNU Classpath.
@@ -50,39 +50,9 @@ public class LocaleInformation_nl extends ListResourceBundle
* This is the same rule as used in the English locale.
*/
private static final String collation_rules =
- "-<0,1<2<3<4<5<6<7<8<9A,a<b,B<c,C<d,D<e,E<f,F<g,G<h,H<i,I<j,J<j,K" +
+ "<0<1<2<3<4<5<6<7<8<9<A,a<b,B<c,C<d,D<e,E<f,F<g,G<h,H<i,I<j,J<k,K" +
"<l,L<m,M<n,N<o,O<p,P<q,Q<r,R<s,S<t,T<u,U<v,V<w,W<x,X<y,Y,z<Z";
-/*
- * For the followings lists, strings that are subsets of other break strings
- * must be listed first. For example, if "\r" and "\r\n" are sequences,
- * the "\r" must be first or it will never be used.
- */
-
-/**
- * This is the list of word separator characters used by
- * java.text.BreakIterator
- * <p>
- * This is the same list as used in the English local
- */
-private static final String[] word_breaks = { " ", "\t", "\r\n", "\n" };
-
-/**
- * This is the list of sentence break sequences used by
- * java.text.BreakIterator
- * <p>
- * This is the same list as used in the English local
- */
-private static final String[] sentence_breaks = { ". " };
-
-/**
- * This is the list of potential line break locations.
- * <p>
- * This is the same list as used in the English local
- */
-private static final String[] line_breaks = { "\t", "-", "\r\n",
- "\n", ". ", ". ", ".", "? ", "? ", "?", "! ", "! ", "!", ", ", " " };
-
/**
* This is the list of months, fully spelled out
*/
@@ -281,10 +251,6 @@ private static final Object[][] contents =
{
// For RuleBasedCollator
{ "collation_rules", collation_rules },
- // For BreakIterator
- { "word_breaks", word_breaks },
- { "sentence_breaks", sentence_breaks },
- { "line_breaks", line_breaks },
// For SimpleDateFormat/DateFormatSymbols
{ "months", months },
{ "shortMonths", shortMonths },
diff --git a/libjava/gnu/java/text/BaseBreakIterator.java b/libjava/gnu/java/text/BaseBreakIterator.java
new file mode 100644
index 0000000..3220253
--- /dev/null
+++ b/libjava/gnu/java/text/BaseBreakIterator.java
@@ -0,0 +1,101 @@
+/* BaseBreakIterator.java -- Base class for default BreakIterators
+ Copyright (C) 1999, 2001 Free Software Foundation, Inc.
+
+This file is part of GNU Classpath.
+
+GNU Classpath is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+GNU Classpath is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with GNU Classpath; see the file COPYING. If not, write to the
+Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+02111-1307 USA.
+
+As a special exception, if you link this library with other files to
+produce an executable, this library does not by itself cause the
+resulting executable to be covered by the GNU General Public License.
+This exception does not however invalidate any other reasons why the
+executable file might be covered by the GNU General Public License. */
+
+
+package gnu.java.text;
+
+import java.text.BreakIterator;
+import java.text.CharacterIterator;
+
+/**
+ * @author Tom Tromey <tromey@cygnus.com>
+ * @date March 22, 1999
+ */
+
+public abstract class BaseBreakIterator extends BreakIterator
+{
+ public int current ()
+ {
+ return iter.getIndex();
+ }
+
+ public int first ()
+ {
+ iter.first();
+ return iter.getBeginIndex();
+ }
+
+ public int following (int pos)
+ {
+ int save = iter.getIndex();
+ iter.setIndex(pos);
+ int r = next ();
+ iter.setIndex(save);
+ return r;
+ }
+
+ public CharacterIterator getText ()
+ {
+ return iter;
+ }
+
+ public int last ()
+ {
+ iter.last();
+ // Go past the last character.
+ iter.next();
+ return iter.getEndIndex();
+ }
+
+ public int next (int n)
+ {
+ int r = iter.getIndex ();
+ if (n > 0)
+ {
+ while (n > 0 && r != DONE)
+ {
+ r = next ();
+ --n;
+ }
+ }
+ else if (n < 0)
+ {
+ while (n < 0 && r != DONE)
+ {
+ r = previous ();
+ ++n;
+ }
+ }
+ return r;
+ }
+
+ public void setText (CharacterIterator newText)
+ {
+ iter = newText;
+ }
+
+ protected CharacterIterator iter;
+}
diff --git a/libjava/gnu/gcj/text/CharacterBreakIterator.java b/libjava/gnu/java/text/CharacterBreakIterator.java
index ba087cc..68207ce 100644
--- a/libjava/gnu/gcj/text/CharacterBreakIterator.java
+++ b/libjava/gnu/java/text/CharacterBreakIterator.java
@@ -1,14 +1,31 @@
-// Default character BreakIterator.
-
-/* Copyright (C) 1999 Free Software Foundation
-
- This file is part of libgcj.
-
-This software is copyrighted work licensed under the terms of the
-Libgcj License. Please consult the file "LIBGCJ_LICENSE" for
-details. */
-
-package gnu.gcj.text;
+/* CharacterBreakIterator.java - Default character BreakIterator.
+ Copyright (C) 1999, 2001 Free Software Foundation, Inc.
+
+This file is part of GNU Classpath.
+
+GNU Classpath is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+GNU Classpath is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with GNU Classpath; see the file COPYING. If not, write to the
+Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+02111-1307 USA.
+
+As a special exception, if you link this library with other files to
+produce an executable, this library does not by itself cause the
+resulting executable to be covered by the GNU General Public License.
+This exception does not however invalidate any other reasons why the
+executable file might be covered by the GNU General Public License. */
+
+
+package gnu.java.text;
import java.text.BreakIterator;
import java.text.CharacterIterator;
diff --git a/libjava/gnu/gcj/text/LineBreakIterator.java b/libjava/gnu/java/text/LineBreakIterator.java
index 4540b7a..14c1b70 100644
--- a/libjava/gnu/gcj/text/LineBreakIterator.java
+++ b/libjava/gnu/java/text/LineBreakIterator.java
@@ -1,14 +1,31 @@
-// Default word BreakIterator.
-
-/* Copyright (C) 1999 Free Software Foundation
-
- This file is part of libgcj.
-
-This software is copyrighted work licensed under the terms of the
-Libgcj License. Please consult the file "LIBGCJ_LICENSE" for
-details. */
-
-package gnu.gcj.text;
+/* LineBreakIterator.java - Default word BreakIterator.
+ Copyright (C) 1999, 2001 Free Software Foundation, Inc.
+
+This file is part of GNU Classpath.
+
+GNU Classpath is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+GNU Classpath is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with GNU Classpath; see the file COPYING. If not, write to the
+Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+02111-1307 USA.
+
+As a special exception, if you link this library with other files to
+produce an executable, this library does not by itself cause the
+resulting executable to be covered by the GNU General Public License.
+This exception does not however invalidate any other reasons why the
+executable file might be covered by the GNU General Public License. */
+
+
+package gnu.java.text;
import java.text.BreakIterator;
import java.text.CharacterIterator;
diff --git a/libjava/gnu/gcj/text/SentenceBreakIterator.java b/libjava/gnu/java/text/SentenceBreakIterator.java
index af2ccf1..9f9e816 100644
--- a/libjava/gnu/gcj/text/SentenceBreakIterator.java
+++ b/libjava/gnu/java/text/SentenceBreakIterator.java
@@ -1,14 +1,31 @@
-// Default sentence BreakIterator.
-
-/* Copyright (C) 1999 Free Software Foundation
-
- This file is part of libgcj.
-
-This software is copyrighted work licensed under the terms of the
-Libgcj License. Please consult the file "LIBGCJ_LICENSE" for
-details. */
-
-package gnu.gcj.text;
+/* SentenceBreakIterator.java - Default sentence BreakIterator.
+ Copyright (C) 1999, 2001 Free Software Foundation, Inc.
+
+This file is part of GNU Classpath.
+
+GNU Classpath is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+GNU Classpath is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with GNU Classpath; see the file COPYING. If not, write to the
+Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+02111-1307 USA.
+
+As a special exception, if you link this library with other files to
+produce an executable, this library does not by itself cause the
+resulting executable to be covered by the GNU General Public License.
+This exception does not however invalidate any other reasons why the
+executable file might be covered by the GNU General Public License. */
+
+
+package gnu.java.text;
import java.text.BreakIterator;
import java.text.CharacterIterator;
diff --git a/libjava/gnu/gcj/text/WordBreakIterator.java b/libjava/gnu/java/text/WordBreakIterator.java
index 553cdef..5cf5014 100644
--- a/libjava/gnu/gcj/text/WordBreakIterator.java
+++ b/libjava/gnu/java/text/WordBreakIterator.java
@@ -1,14 +1,31 @@
-// Default word BreakIterator.
-
-/* Copyright (C) 1999 Free Software Foundation
-
- This file is part of libgcj.
-
-This software is copyrighted work licensed under the terms of the
-Libgcj License. Please consult the file "LIBGCJ_LICENSE" for
-details. */
-
-package gnu.gcj.text;
+/* WordBreakIterator.java - Default word BreakIterator.
+ Copyright (C) 1999, 2001 Free Software Foundation, Inc.
+
+This file is part of GNU Classpath.
+
+GNU Classpath is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+GNU Classpath is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with GNU Classpath; see the file COPYING. If not, write to the
+Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+02111-1307 USA.
+
+As a special exception, if you link this library with other files to
+produce an executable, this library does not by itself cause the
+resulting executable to be covered by the GNU General Public License.
+This exception does not however invalidate any other reasons why the
+executable file might be covered by the GNU General Public License. */
+
+
+package gnu.java.text;
import java.text.BreakIterator;
import java.text.CharacterIterator;